searchData={"items":[{"type":"module","title":"Archive","doc":"`Archive` provides Elixir bindings to [`libarchive`](https://github.com/libarchive/libarchive) through the power of the wonderful [`Zigler`](https://hexdocs.pm/zigler/Zig.html) library.\n\n`Archive` provides a high-level API for interacting with archive files. \n\nLike `libarchive`, `Archive` treats all files as streams first and foremost, but provides many convenient high-level APIs to make it more natural to work with archive.\n\n> #### Early Development {: .warning}\n>\n> `Archive` is still very early in its development, and currently only supports reading archives with all formats, compressions, and filters enabled. In the future, these will be configurable parameters.","ref":"Archive.html"},{"type":"module","title":"Reading - Archive","doc":"As streams, archives are not conducive to random-access reads or seeks. Once archives are opened and read, they must be closed and reopened to read again. It is often a two-stage process to read an archive, where you read a list of the contents first, then selectively filter which items you want suring a second pass. \n\n`Archive` takes care of all resource allocations, initializations, and cleanup for you. Using the high-level API, you only need to provide a mapping function to determine what to do with each entry as it is streamed.\n\n> #### The Low-Level Reading Loop {: .info}\n>\n> Although `Archive`'s high-level API takes care of all of the resource management for you, it can still be useful to understand how it works:\n>   1) Create new archive reader object\n>   2) Update any global reader properties as appropriate. These properties determine supported compressions, formats, etc.\n>   3) Open the archive\n>   4) Repeatedly call archive_read_next_header to get information about\n>       successive archive entries.  Call archive_read_data to extract\n>      data for entries of interest.\n>   5) Cleanup archive reader object \n\nThe mapping function will accept an `Archive.Entry` struct, which will contain metadata (such as path and size) information about the entry. You can use that information to determine what to do in your function.\n\nYou can also use function from the `Archive.Entry` module to perform different operations with the entry (most commonly `Archive.Entry.load/1`).\n\n> #### Usage of `Archive.Entry` functions {: .error}\n>\n> It is generally discouraged to use function from the `Archive.Entry` module outside of the context of a function passed to the high-level API.\n>\n> As mentioned earlier, since archives are all streaming objects, each entry can only be operated on while it is the current entry in the stream. If you try to use functions from the `Archive.Entry` module while outside of the loop you provide to the various high-level APIs, it is up to you to ensure that the entry owns the reference to the archive object (`:ref` key in the `Archive.Entry` struct). Most functions do not work when `:ref` is `nil`. The high-level API takes care of ensuring that the `Archive.Entry` has the reference when your function is applied to it.","ref":"Archive.html#module-reading"},{"type":"module","title":"Examples - Archive","doc":"Setup the archive\n\n```elixir\ndata = File.read!(\"/path/to/data.zip\")\n{:ok, a} = Archive.new()\n```\n\nRead the index of entries. Notice that the output of inspection\nwill show you how many items are in the archive (given the function you supplied to `Archive.read/3`), the archive format, the size of the archive, and more.\n\n```elixir\n{:ok, a} = Archive.read(a, data)\n```\n\n```\n{:ok, #Archive[zip]<\n 147 entries (0 loaded), 506.0 KB\n ───────────────\n   .editorconfig (166 B)\n   .github/ (1 items, 338 B)\n     workflows/ (1 items, 338 B)\n       deploy-theme.yml (338 B)\n   ... and 21 more\n>}\n```\n\nHere's an example of reading into memory all entries that are larger than 1500 bytes, and store the entries as a list (rather than as a hierarchical map):\n\n```elixir\n{:ok, a} =\nArchive.read(a, data,\n  with: fn entry ->\n    if entry.size > 1500 do\n      {:ok, entry} = Archive.Entry.load(entry)\n      entry\n    else\n      entry\n    end\n    end, as: :list\n)\n```\n\n```\n{:ok, #Archive[zip]<\n 147 entries (40 loaded), 506.0 KB\n ───────────────\n   .editorconfig (166 B)\n   .github/ (1 items, 338 B)\n     workflows/ (1 items, 338 B)\n       deploy-theme.yml (338 B)\n   ... and 21 more\n>}\n```","ref":"Archive.html#module-examples"},{"type":"module","title":"Writing - Archive","doc":"> #### TODO {: .error}\n> \n> `Archive` is still very early in development and does not implement any of the writing API yet.\n\n\n## `Inspect`\n\n`Archive` and `Archive.Entry` provide custom implementations for the `Inspect` protocol. \n\nWhen inspecting `Archive`, the following custom options can be supplied to the `custom_options` option of inspect:\n\n* `:depth` - Depth of directories to display. Defaults to 3.\n* `:breadth` - Breadth of items to display. Defaults to 2.","ref":"Archive.html#module-writing"},{"type":"module","title":"Examples - Archive","doc":"```elixir\nIO.inspect(%Archive{} = a, custom_options: [depth: 3, breadth: 2])\n```\n\n```\n#Archive[zip]<\n147 entries (40 loaded), 506.0 KB\n───────────────\n  .editorconfig (166 B)\n  .github/ (1 items, 338 B)\n    workflows/ (1 items, 338 B)\n      deploy-theme.yml (338 B)\n  ... and 21 more\n>\n```","ref":"Archive.html#module-examples"},{"type":"function","title":"Archive.from_file_streaming/3","doc":"Streams the contents of an archive from a file, applying the supplied function to each entry.","ref":"Archive.html#from_file_streaming/3"},{"type":"function","title":"Archive.from_memory_streaming/3","doc":"Streams the contents of an archive from memory, applying the supplied function to each entry.","ref":"Archive.html#from_memory_streaming/3"},{"type":"function","title":"Archive.hierarchical/1","doc":"Converts a list of `Archive.Entry` to a hierachical map, similar to a filesystem structure.","ref":"Archive.html#hierarchical/1"},{"type":"function","title":"Archive.init/2","doc":"Initializes an `Archive` with the appropriate settings and properties.\n\n> #### Properties and Settings {: .info}\n>\n> Currently, the properties and settings are not configurable. The default is to support all archive formats (including raw), all compression formats, and not filter any entries. \n> \n> In the future, `init/2` will accept options for all of these to setup the reader / writer in the appropriate modes","ref":"Archive.html#init/2"},{"type":"function","title":"Archive.new/0","doc":"Creates a new `Archive` struct. This must be initialized before any IO operations can occur.","ref":"Archive.html#new/0"},{"type":"function","title":"Archive.read/3","doc":"Reads the content of an archive.\n\nThis function populates meta-data about the archive, such as total archive size and archive format.","ref":"Archive.html#read/3"},{"type":"function","title":"Options - Archive.read/3","doc":"* `:with` - Applies the supplied function to each `Archive.Entry`. Defaults to the identity function.\n* `:as` - How to collect the entries. Can be `:list` or `:map`, where `:map` creates a hierarchical filesystem-like representation of the entries. Defaults to `:map`.","ref":"Archive.html#read/3-options"},{"type":"module","title":"Archive.Entry","doc":"`Archive.Entry` represents a single item in an archive.\n\nMost functions in this module will only work within the context of the aupplied mapping function given to `Archive.read/3`. This is because these functions require a reference to the archive while streaming and while the entry is the current item in the stream.","ref":"Archive.Entry.html"},{"type":"function","title":"Archive.Entry.load/1","doc":"Loads the entry into the archive whose reference is held by the entry. The reference to the archive is automatically passed to the current entry during `Archive.read/3`, `Archive.from_memory_streaming/3`, and `Archive.from_file_streaming/3`.","ref":"Archive.Entry.html#load/1"},{"type":"function","title":"Archive.Entry.new/0","doc":"Creates a new `Archive.Entry` struct. This is done implicitly during `Archive.read/3`.","ref":"Archive.Entry.html#new/0"},{"type":"module","title":"Archive.Nif","doc":"","ref":"Archive.Nif.html"},{"type":"function","title":"Archive.Nif.archive_clear_error/1","doc":"","ref":"Archive.Nif.html#archive_clear_error/1"},{"type":"function","title":"Archive.Nif.archive_entry_new/0","doc":"","ref":"Archive.Nif.html#archive_entry_new/0"},{"type":"function","title":"Archive.Nif.archive_entry_pathname/1","doc":"","ref":"Archive.Nif.html#archive_entry_pathname/1"},{"type":"function","title":"Archive.Nif.archive_entry_size/1","doc":"","ref":"Archive.Nif.html#archive_entry_size/1"},{"type":"function","title":"Archive.Nif.archive_error_string/1","doc":"","ref":"Archive.Nif.html#archive_error_string/1"},{"type":"function","title":"Archive.Nif.archive_file_count/1","doc":"","ref":"Archive.Nif.html#archive_file_count/1"},{"type":"function","title":"Archive.Nif.archive_format/1","doc":"","ref":"Archive.Nif.html#archive_format/1"},{"type":"function","title":"Archive.Nif.archive_format_name/1","doc":"","ref":"Archive.Nif.html#archive_format_name/1"},{"type":"function","title":"Archive.Nif.archive_read_close/1","doc":"","ref":"Archive.Nif.html#archive_read_close/1"},{"type":"function","title":"Archive.Nif.archive_read_data/2","doc":"","ref":"Archive.Nif.html#archive_read_data/2"},{"type":"function","title":"Archive.Nif.archive_read_new/0","doc":"","ref":"Archive.Nif.html#archive_read_new/0"},{"type":"function","title":"Archive.Nif.archive_read_next_header/2","doc":"","ref":"Archive.Nif.html#archive_read_next_header/2"},{"type":"function","title":"Archive.Nif.archive_read_open_filename/3","doc":"","ref":"Archive.Nif.html#archive_read_open_filename/3"},{"type":"function","title":"Archive.Nif.archive_read_open_memory/2","doc":"","ref":"Archive.Nif.html#archive_read_open_memory/2"},{"type":"function","title":"Archive.Nif.archive_read_support_compression_all/1","doc":"","ref":"Archive.Nif.html#archive_read_support_compression_all/1"},{"type":"function","title":"Archive.Nif.archive_read_support_filter_all/1","doc":"","ref":"Archive.Nif.html#archive_read_support_filter_all/1"},{"type":"function","title":"Archive.Nif.archive_read_support_format_all/1","doc":"","ref":"Archive.Nif.html#archive_read_support_format_all/1"},{"type":"function","title":"Archive.Nif.archive_read_support_format_raw/1","doc":"","ref":"Archive.Nif.html#archive_read_support_format_raw/1"},{"type":"function","title":"Archive.Nif.safe_call/2","doc":"","ref":"Archive.Nif.html#safe_call/2"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}